summaryrefslogtreecommitdiffstats
path: root/conduits/abbrowserconduit/resolutionDialog.cc
diff options
context:
space:
mode:
Diffstat (limited to 'conduits/abbrowserconduit/resolutionDialog.cc')
-rw-r--r--conduits/abbrowserconduit/resolutionDialog.cc28
1 files changed, 14 insertions, 14 deletions
diff --git a/conduits/abbrowserconduit/resolutionDialog.cc b/conduits/abbrowserconduit/resolutionDialog.cc
index d9b7089..0064a68 100644
--- a/conduits/abbrowserconduit/resolutionDialog.cc
+++ b/conduits/abbrowserconduit/resolutionDialog.cc
@@ -43,15 +43,15 @@
* as well as its child radio buttons. There are two different constructors
* for them.
* Each controller has three child radio buttons, and if any of them is
* activated (stateChange), it sets the text of its parent (which is the
* controller, which is an instance of ResolutionCheckListItem, too).
**/
class ResolutionCheckListItem : TQCheckListItem {
public:
ResolutionCheckListItem(ResolutionItem*it, ResolutionTable*tb,
- TQListView*parent);
+ TQListView*tqparent);
ResolutionCheckListItem(TQString header, TQString text,
- ResolutionCheckListItem*parent);
+ ResolutionCheckListItem*tqparent);
~ResolutionCheckListItem() {};
virtual void stateChange(bool newstate);
virtual void setValue(TQString text);
@@ -73,12 +73,12 @@ protected:
ResolutionCheckListItem::ResolutionCheckListItem(ResolutionItem*it,
- ResolutionTable*tb, TQListView*parent) :
- TQCheckListItem(parent, TQString::null, TQCheckListItem::Controller),
+ ResolutionTable*tb, TQListView*tqparent) :
+ TQCheckListItem(tqparent, TQString(), TQCheckListItem::Controller),
fResItem(it),
isController(true),
- fCaption(it?(it->fName):(TQString::null)),
- fText(it?(it->fResolved):(TQString::null))
+ fCaption(it?(it->fName):(TQString())),
+ fText(it?(it->fResolved):(TQString()))
{
FUNCTIONSETUP;
if (it && tb)
@@ -119,8 +119,8 @@ ResolutionCheckListItem::ResolutionCheckListItem(ResolutionItem*it,
}
ResolutionCheckListItem::ResolutionCheckListItem(TQString text, TQString header,
- ResolutionCheckListItem*parent) :
- TQCheckListItem(parent, TQString(), TQCheckListItem::RadioButton),
+ ResolutionCheckListItem*tqparent) :
+ TQCheckListItem(tqparent, TQString(), TQCheckListItem::RadioButton),
fResItem(0L),
isController(false),
fCaption(header),
@@ -133,7 +133,7 @@ void ResolutionCheckListItem::stateChange(bool newstate)
{
if (newstate && !isController)
{
- ResolutionCheckListItem*par=static_cast<ResolutionCheckListItem*>(parent());
+ ResolutionCheckListItem*par=static_cast<ResolutionCheckListItem*>(tqparent());
{
par->setValue(fText);
}
@@ -159,7 +159,7 @@ void ResolutionCheckListItem::setCaption(TQString caption)
void ResolutionCheckListItem::updateText()
{
- TQString newText(i18n("Entries in the resolution dialog. First the name of the field, then the entry from the Handheld or PC after the colon", "%1: %2").arg(fCaption).arg(fText));
+ TQString newText(i18n("Entries in the resolution dialog. First the name of the field, then the entry from the Handheld or PC after the colon", "%1: %2").tqarg(fCaption).tqarg(fText));
newText.tqreplace(TQRegExp(CSL1("\n")),
i18n("Denoting newlines in Address entries. No need to translate", " | "));
setText(0, newText);
@@ -171,9 +171,9 @@ void ResolutionCheckListItem::updateText()
*
*****************************************************************/
-ResolutionDlg::ResolutionDlg( TQWidget* parent, KPilotLink*fH,
+ResolutionDlg::ResolutionDlg( TQWidget* tqparent, KPilotLink*fH,
const TQString &caption, const TQString &helpText, ResolutionTable*tab) :
- KDialogBase( parent, "ResolutionDlg", false, caption, Apply|Cancel, Apply),
+ KDialogBase( tqparent, "ResolutionDlg", false, caption, Apply|Cancel, Apply),
tickleTimer(0L),
fHandle(fH),
fTable(tab)
@@ -319,5 +319,5 @@ void ResolutionDlg::_tickle()
*/
ResolutionDlg::~ResolutionDlg()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
@@ -43,15 +43,15 @@
* for them.
* Each controller has three child radio buttons, and if any of them is
- * activated (stateChange), it sets the text of its parent (which is the
+ * activated (stateChange), it sets the text of its tqparent (which is the
* controller, which is an instance of ResolutionCheckListItem, too).
**/